==> haskell-http-conduit-2.3.7.1-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.3.7.1
id: http-conduit-2.3.7.1-IliglbYlp2a1JIiNe3n5cf
key: http-conduit-2.3.7.1-IliglbYlp2a1JIiNe3n5cf
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.
category: Web, Conduit
abi: 3bb7f580f3caf58f04a94a2fc310e276
exposed: True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-conduit-2.3.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-conduit-2.3.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-conduit-2.3.7.1
hs-libraries: HShttp-conduit-2.3.7.1-IliglbYlp2a1JIiNe3n5cf
depends:
    aeson-1.4.4.0-8EzwlpxsJYiJGXz8JVXZ1i
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-7rGn2miUuc0IzsMPA6GM7m
    conduit-extra-1.3.2-2xarBShtmoTHDN9knVQRhr
    http-client-0.6.4-LC2XTclyTBtLSxSxXQXavF
    http-client-tls-0.3.5.3-JMPgLQAo3UE13O2HNdBa5j
    http-types-0.12.3-4KWln6jzZFqKSBXaEIoMvB mtl-2.2.2
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c transformers-0.5.6.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.3.7.1-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.3.7.1
id: http-conduit-2.3.7.1-2QrTCTUeO2R1ar6JmbSyHS
key: http-conduit-2.3.7.1-2QrTCTUeO2R1ar6JmbSyHS
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.
category: Web, Conduit
abi: be9b37be9afd04c62a6be6074d0f5b41
exposed: True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-conduit-2.3.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-conduit-2.3.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-conduit-2.3.7.1
hs-libraries: HShttp-conduit-2.3.7.1-2QrTCTUeO2R1ar6JmbSyHS
depends:
    aeson-1.4.4.0-7vLg8fT3jLZEAAmFwxYKHF
    attoparsec-0.13.2.2-4cHpHFFBuyN5UF0oDRVEML base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-JSdi7R8L6wUIGZiBi8qKpO
    conduit-extra-1.3.2-D50RCH6hLiF4M9x0U29P7E
    http-client-0.6.4-2vvZT4nV8ZwJDNuwGeFyhx
    http-client-tls-0.3.5.3-Au4LL1tAcd0ClbEGyFVtJV
    http-types-0.12.3-BsfSThCiYntF94Mfs0JU92 mtl-2.2.2
    resourcet-1.2.2-BD7KiCA7p3Q4m6RD0qps5k transformers-0.5.6.2
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
